# Functions that build a data package using GO data
#

GOPkgBuilder <- function(pkgName = "GO", pkgPath, version = "1.2.1",
                         srcUrl = getSrcUrl("GO", xml = TRUE),
                         author = list(author = "who",
                         maintainer = "who@email.com")){
    print("It may take me a while to process the data. Be patient!")
    if(missing(pkgPath)){
        pkgPath <- getwd()
    }
    # A matrix to keep GO ids and group (CC, BP, MF) information
    goNGroup <- cbind(getTopGOid("GO"), "GO")
    makeSrcInfo()
    go <- GO(srcUrl)
    goData <- readData(go, xml = TRUE)
    # Create a data package with no data
    createEmptyDPkg(pkgName, pkgPath, force = TRUE)
    # Write the association data
#    env <- new.env(hash = TRUE, parent = NULL)
#    multiassign(goData[,1], splitChromData(goData[, 4]), env)
#    assign(paste(pkgName, "ASSOCIATION", sep = ""), env)
#    save(list = paste(pkgName, "ASSOCIATION", sep = ""),
#         file =  file.path(pkgPath, pkgName, "data",
#         paste(pkgName, "ASSOCIATION", ".rda", sep = "")))
    # Process data for MF, CC, and BP and write the data to parents
    # and ontology term data file
    goGroups <- getGOGroupIDs()
    for(i in names(goGroups)){
        goids <- c(as.vector(goGroups[i]),
                   getOffspringNodes(goGroups[i], goData))
        # Map GO ids to the three ontology categories.
        goNGroup <- rbind(goNGroup, cbind(goids, i))
        temp <- goData[is.element(unique(goData[,1]), goids),]
        # Write GO id to parent GO id data file
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(temp[,1], sapply(temp[, 4], twoStepSplit), env)
        assign(paste(pkgName, i, "PARENTS", sep = ""), env)
        save(list = paste(pkgName, i, "PARENTS", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "PARENTS", ".rda", sep = "")))
        # Write Ontology file
        env <- new.env(hash = TRUE, parent = NULL)
        tempTerm <- goData[is.element(unique(goData[,1]),
                                      c(getTopGOid("GO"), goids)),]
        multiassign(temp[,1], sapply(temp[, 3], splitEntry), env)
        assign(paste(pkgName, i, "ID2TERM", sep = ""), env)
        save(list = paste(pkgName, i, "ID2TERM", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "ID2TERM", ".rda", sep = "")))
        # Write GO id to children GO id data file
        temp <- sapply(goids, getChildNodes, goData = goData)
        temp <- sapply(temp, paste, sep = "", collapse = ";")
        # Write GO id to parent GO id data file
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(names(temp), sapply(temp, splitEntry), env)
        assign(paste(pkgName, i, "CHILDREN", sep = ""), env)
        save(list = paste(pkgName, i, "CHILDREN", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "CHILDREN", ".rda", sep = "")))
    }
    # Write the mapping between GO ids and category information
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(goNGroup[,1], goNGroup[,2], env)
    assign(paste(pkgName, "CATEGORY", sep = ""), env)
    save(list = paste(pkgName, "CATEGORY", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "CATEGORY", ".rda", sep = "")))
    # Write man pages and other files
    writeAccessory(pkgName, pkgPath, organism = "GO",
                   version = version, author = author)
    # Quality control
    getDPStats("", pkgName, pkgPath)
    writeMan4QC(pkgName, pkgPath)
}













