# Constructs an object of GP for Golden Path data
#

GP <- function(srcUrl = getSrcUrl("UCSC", "human"), organism = "human",
               parser = "", baseFile = ""){

    new("GP", srcUrl = srcUrl, organism = organism, parser = parser,
        baseFile = baseFile)
}

getChroLocation <- function(srcUrl, exten = gpLinkNGene(), sep = "\t",
                            fromWeb = TRUE, raw = FALSE){
    if(fromWeb){
        # Tow source data files are needed.
        linkData <- getGPData(paste(srcUrl, exten["link"], sep = ""),
                              sep = "\t", ncol = 8, keep = c(3,7))
        locatData <- getGPData(paste(srcUrl, exten["gene"], sep = ""),
                               ncol = 10, keep = c(1:5))
    }else{
        linkData <- read.table(srcUrl["link"], sep = sep, header = FALSE,
                               as.is = TRUE)
        linkData <- linkData[, c(3, 7)]
        locatData <- read.table(srcUrl["gene"], sep = sep, header = FALSE,
                                as.is = TRUE)
        locatData <- locatData[, c(1:4)]
    }
    colnames(linkData) <- c("ID", "LOCUSID")
    # Remove "chr" proceeding chromosome number
    locatData[, 2] <- gsub("^chr", "\\", locatData[, 2])
    if(raw){
        colnames(locatData) <- c("ID", "CHR", "STRAND", "START", "END")
        merged <- as.matrix(merge(linkData, locatData, by = "ID",
                                  all.x = TRUE))
        merged <- merged[, 2:6]
        # Remove <NA>s that are introduced by droping the ID column
        merged <- merged[!is.na(merged[,1]), ]
        return(merged)
    }
    # for - strand, end locations should be strat locations
    locatData <- rbind(locatData[locatData[,3] == "+", c(1:4)],
                       locatData[locatData[,3] == "-", c(1, 2, 3, 5)])
    # Put sign to locations
    locatData[, 4] <- paste(locatData[,3], locatData[,4], sep = "")
    locatData <- cbind(locatData[, 1], paste(locatData[, 4], "@",
                 locatData[,2], sep = ""))
    colnames(locatData) <- c("ID", "CHRLOC")
    merged <- as.matrix(merge(linkData, locatData, by = "ID",
                              all.x = TRUE)[, 2:3])
    # Remove <NA>s that are introduced by droping the ID column
    merged <- merged[!is.na(merged[,1]), ]
    return(mergeRowByKey(merged))
}

getGPData <- function(srcUrl, sep = "\t", ncol = 8, keep = c(3,7)){
    temp <- loadFromUrl(srcUrl)
    gpData <- matrix(scan(temp, what = "", sep = sep, quote = "",
                          strip.white = TRUE, quiet = TRUE), ncol = ncol,
                     byrow = TRUE)[,keep]
    unlink(temp)
    return(gpData)
}

gpLinkNGene <- function(test = FALSE){
    if(test){
        return(c(link = "Tlink.txt", gene = "TGene.txt"))
    }else{
        return(c(link = "refLink.txt.gz", gene = "refGene.txt.gz"))
    }
}

# No in use at this time
#gpParser <- function(){
#    c(link = file.path(.path.package("pubRepo"), "data", "gpLinkParser"),
#      gene = file.path(.path.package("pubRepo"), "data", "gpGeneParser"))
#}

