# Constructors an object of KEGG
#

KEGG <- function(srcUrl = "ftp://ftp.genome.ad.jp/pub/kegg/pathways",
                 organism = "human", parser = "", baseFile = ""){

    new("KEGG", srcUrl = srcUrl, organism = organism, parser = parser,
        baseFile = baseFile)
}

getKEGGIDNName <- function(srcUrl, exten = "/map_title.tab" ){
    con <- url(paste(srcUrl, exten, sep = ""), "r")
    temp <- matrix(unlist(strsplit(readLines(con), "\t")),
                                      ncol = 2, byrow = TRUE)
    close(con)
    idNName <- temp[,2]
    names(idNName) <- temp[,1]
    return(idNName)
}

getKEGGOrgName <- function(name){
    switch(name,
           "human" = return("hsa"),
           "mouse" = return("mmu"),
           "rat" = return("rno"),
           "yeast" = return("sce"),
           stop("The organism is not supported"))
}

getLLPathMap <- function(srcUrl, idNName, organism){
    llEC <- NULL
    llPathName <- NULL
    # Get ll to EC and pathway name mappings
    for(i in names(idNName)){

        temp <- mapll2EC(i, srcUrl = srcUrl, organism)
        if(!is.null(temp)){
            temp <- t(sapply(temp, parseEC))
            # Map ll to EC
            if(is.null(llEC)){
                llEC <- temp[!is.na(temp[,2]),]
            }else{
                llEC <- rbind(llEC, temp[!is.na(temp[,2]),] )
            }
            # Map ll to pathway name
            if(length(unique(temp[,1])) <= 1){
                tempPN <- matrix(c(unique(temp[,1]), i), ncol = 2)
            }else{
                tempPN <- cbind(unique(temp[, 1]), i)
            }
            if(is.null(llPathName)){
                llPathName <- tempPN
            }else{
                llPathName <- rbind(llPathName, tempPN)
            }
        }
    }
    colnames(llEC) <- c("LOCUSID", "ENZYME")
    colnames(llPathName) <- c("LOCUSID", "PATH")
    return(list(llec = mergeRowByKey(llEC),
                llpathname = mergeRowByKey(llPathName)))
}


# Returns a matrix with Locus link ids as the first column and EC as
# second one with NA for ll not mapped to EC
mapll2EC <- function(id, srcUrl, organism, sep = "\t"){
    tempURL <- paste(srcUrl,"/", getKEGGOrgName(organism),
                     "/", getKEGGOrgName(organism), as.character(id),
                     ".gene", sep = "")

    on.exit(options(show.error.messages = TRUE))

    temp <- NULL
    con <- url(tempURL)
    options(show.error.messages = FALSE)
    llNEC <- try(readLines(con))
    close(con)
    options(show.error.messages = TRUE)

    if(!inherits(llNEC, "try-error")){
        temp <- strsplit(llNEC, split = sep)
#        temp <- t(sapply(temp, parseEC))
#        temp <- temp[!is.na(temp[,2]),]
        return(temp)
    }else{
        return(NULL)
    }
}

parseEC <- function(llNEC){
    if(length(grep(".*\\[EC:[0-9|\\.|-| ]*", llNEC[2])) != 0){
        EC <- strsplit(strsplit(llNEC[2], "\\[EC:")[[1]][2], "\\]")[[1]][1]
        # Collapse multiple EC number
        EC <- paste(unlist(strsplit(EC, " "), use.names = FALSE),
                    collapse = ";")

        return(c(llNEC[1], EC))
    }else{
        return(c(llNEC[1], NA))
    }
}













