# Functions that return the built date for a given public source.
#
# Copyright 2002, J. Zhang, all rights reserved
#

getSrcBuilt <- function(src = "LL", organism = "human"){
    switch(toupper(src),
           "LL" = return(getLLBuilt()),
           "UG" = return(getUGBuilt(organism)),
           "GP" = return(getUCSCBuilt(organism)),
           "GO" = return(getGOBuilt()),
           "KEGG" = return(getKEGGBuilt()),
           "YG" = return(getYGBuilt()),
           "HG" = return(getHGBuilt()),
           stop(paste("Source", src, "is not supported.")))
}

getLLBuilt <- function(
        url = "http://www.ncbi.nlm.nih.gov/LocusLink/statistics.html"){

    got <- readURL(url)
    built <- gsub(".*LocusLink Statistics dated (.*)",
                  "\\1", got[grep("LocusLink Statistics dated", got)])
    if(is.na(built) || is.null(built) || built == ""){
        waringing("Built for LL is not valid!")
        return("N/A")
    }else{
        return(built)
    }
}

getUGBuilt <- function(organism,
                       url = "ftp://ftp.ncbi.nih.gov/repository/UniGene"){

    switch(toupper(organism),
           "HUMAN" = infoUrl <- paste(url, "/Hs.info", sep = ""),
           "MOUSE" = infoUrl <- paste(url, "/Mm.info", sep = ""),
           "RAT" = infoUrl <- paste(url, "/Rn.info", sep = ""),
           stop(paste("Organism", organism, "is not supported.")))

    got <- readURL(infoUrl)
    built <- gsub(".*(Build #[0-9]*).*", "\\1",
                  got[grep("Build #", got)[1]])
    if(is.na(built) || is.null(built) || built == ""){
        waringing("Built for UG is not valid!")
        return("N/A")
    }else{
        return(built)
    }
}

getUCSCBuilt <- function(organism){
    url <- getSrcUrl(src = "GP", organism = organism)
    switch(toupper(organism),
           MOUSE =  built <- gsub(".*goldenPath/mm(.*)/database.*",
                           "\\1", url),
           HUMAN = built <- gsub(".*goldenPath/(.*)/database.*", "\\1", url),
           RAT = built <- gsub(".*goldenPath/rn(.*)/database.*",
                           "\\1", url),
           stop(paste("Organism", organism, "is not supported")))

    if(is.na(built) || is.null(built) || built == ""){
        waringing("Built for UCSC is not valid!")
        return("N/A")
    }else{
        return(built)
    }
}

getGOBuilt <- function(){
   return(getGOUrl(xml = TRUE, dateOnly = TRUE))
}

getKEGGBuilt <- function(url = "http://www.genome.ad.jp/kegg/kegg2.html"){

    got <- readURL(url)
    aLine <- got[grep("KEGG Release", got)]
    built <- gsub(".*(Release [0-9.]* \\(.*\\)) .*", "\\1", aLine)
    if(is.na(built) || is.null(built) || built == ""){
        waringing("Built for KEGG is not valid!")
        return("N/A")
    }else{
        return(built)
    }
}

getYGBuilt <- function(){
    return(paste("Yeast Genome data are built at various time ",
                 "intervals. Sources used were downloaded ", date(), "\n"))
}

readURL <- function(url){
    con <- url(url)
    options(show.error.messages = FALSE)
    temp <- try(readLines(con))
    close(con)
    options(show.error.messages = TRUE)
    if(!inherits(temp, "try-error")){
        return(temp)
    }else{
        stop(paste("Can't read from url:", url))
    }
}

getHGBuilt <- function(){
    return("HomoloGene built date not available")
}











