\name{getChroLocation}
\alias{getChroLocation}
\alias{getGPData}
\alias{gpLinkNGene}
\title{Functions to extract data from golden path}
\description{
  These functions are used by objects GP to extract chromosomal location
  and orientation data for genes.
}
\usage{
getChroLocation(srcUrl, exten = gpLinkNGene(), sep = "\t", fromWeb =
TRUE, raw = FALSE)
getGPData(srcUrl, sep = "\t", ncol = 8, keep = c(3,7))
gpLinkNGene(test = FALSE)
}
\arguments{
  \item{srcUrl}{\code{srcUrl} a character string for the url where
    source data are available}
  \item{exten}{\code{exten} a character string for the name of the file
    to be used for the extraction}
  \item{sep}{\code{sep} a character string for the separater used by the
    source file}
  \item{ncol}{\code{ncol} an integer for the total number of columns a
    source data set has}
  \item{keep}{\code{keep} a numeric vector for the columns (defined by
    column number) to be kept}
  \item{test}{\code{test} a boolean to indicate whether the process is
    in a testing mode}
  \item{fromWeb}{\code{fromWeb} a boolean to indicate whether the source
    data should be downloaded from the web or is a local file}
  \item{raw}{\code{raw} a boolean indicating whether chromosomal loation
    data will be returned as a five column data frame with ID,
    Chromosome, strand, start, and end or a two column data with ID and
    processed chromosome location data}
}
\details{
  \code{\link{getChroLocation}} extracts chromosomal location data from
  a data file named refGene.

  \code{\link{getGPData}} Reads data from a source data file defined by
  srcUrl and returns them as a matrix.

  \code{\link{gpLinkNGene}} returns a correct link and gene data file
  names that will be used to get chromosomal location data.
}
\value{
  \code{\link{getChroLocation}} returns a matrix with the first column
  being LocusLink ids, the second being the chromosomal location, and
  third being the orientation for that locus.

  \code{\link{getGPData}} returns a matrix.

  \code{\link{gpLinkNGene}} returns a named vector.
}
\references{\url{http://www.genome.ucsc.edu}}
\author{Jianhua Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide Bioinformatics functionalities through R}

\seealso{\code{\link{GP}}}
\examples{
# Truncated versions of files stored in Bioconductor site are used
gpLinkNGene(test = FALSE)
temp <- getGPData(
"http://www.bioconductor.org/datafiles/wwwsources/Tlink.txt",
sep = "\t", ncol = 8, keep = c(3,7))
temp <- getChroLocation(
"http://www.bioconductor.org/datafiles/wwwsources/",
exten = gpLinkNGene(TRUE), sep = "\t")
}
\keyword{manip}

